summaryrefslogtreecommitdiffstats
path: root/kmail/imapaccountbase.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/imapaccountbase.h')
-rw-r--r--kmail/imapaccountbase.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmail/imapaccountbase.h b/kmail/imapaccountbase.h
index d9f3e7cb..533be483 100644
--- a/kmail/imapaccountbase.h
+++ b/kmail/imapaccountbase.h
@@ -231,13 +231,13 @@ namespace KMail {
* Set the status on the server
* Emits imapStatusChanged signal on success/error.
*/
- void setImapStatus( KMFolder* folder, const TQString& path, const TQCString& flags );
+ void setImaptqStatus( KMFolder* folder, const TQString& path, const TQCString& flags );
/**
* Set seen status on the server.
* Emits imapStatusChanged signal on success/error.
*/
- void setImapSeenStatus( KMFolder* folder, const TQString& path, bool seen );
+ void setImapSeentqStatus( KMFolder* folder, const TQString& path, bool seen );
/**
* The KIO-Slave died
@@ -597,7 +597,7 @@ namespace KMail {
/**
* Emitted upon completion of the job for setting the status for a group of UIDs,
* as a result of a setImapStatus call.
* On error, if the user chooses abort (not continue), cont is set to false.
*/
void imapStatusChanged( KMFolder*, const TQString& imapPath, bool cont );
@@ -597,7 +597,7 @@ namespace KMail {
/**
* Emitted upon completion of the job for setting the status for a group of UIDs,
- * as a result of a setImapStatus call.
+ * as a result of a setImaptqStatus call.
* On error, if the user chooses abort (not continue), cont is set to false.
*/